@@ -20,11 +20,17 @@ sub new {
     my @unknown = grep not( /\A(?:file|source)\z/ ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
 
     # Call BUILD methods
-    unless ( $no_build ) { $_->($self, $args) for @{ $meta->{BUILD} || [] } };
+    $self->BUILDALL( $args ) if ( ! $no_build and @{ $meta->{BUILD} || [] } );
 
     return $self;
 }
 
+sub BUILDALL {
+    my $class = ref( $_[0] );
+    my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+    $_->( @_ ) for @{ $meta->{BUILD} || [] };
+}
+
 sub DESTROY {
     my $self  = shift;
     my $class = ref( $self ) || $self;
@@ -58,6 +64,7 @@ sub __META__ {
             map { "$_\::DEMOLISH" } @$linear_isa
         ],
         HAS_BUILDARGS => $class->can('BUILDARGS'),
+        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
     };
 }
 
